// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_LOG_KIO_MTP_KIO_MTP_DEBUG_H
#define ECM_QLOGGINGCATEGORY_LOG_KIO_MTP_KIO_MTP_DEBUG_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(LOG_KIO_MTP)


#endif
